<?php
/**
 * netube functions and definitions
 *
 */
/**
 * netube predifined vars
 */
define('NETUBE_ADMIN', get_template_directory().'/admin');
define('NETUBE_INC', get_template_directory().'/inc');
define('NETUBE_THEME_ELEMENTS', get_template_directory().'/admin/theme-elements');
define('NETUBE_ADMIN_URL', get_template_directory_uri().'/admin');
define('NETUBE_INC_URL', get_template_directory_uri().'/inc');
define('NETUBE_ASSETS', get_template_directory_uri().'/assets');

$netube_option = get_option( 'netube_options' );

//Theme Default
require_once NETUBE_ADMIN . '/theme-default/theme-default.php';

//Theme Class
require_once NETUBE_INC . '/theme-class/theme-class.php';

//Theme Options
require_once NETUBE_THEME_ELEMENTS . '/theme-options.php';
//Custom Sidebar
require_once NETUBE_ADMIN . '/custom-sidebar/sidebar-generator.php';
//TGM
require_once NETUBE_ADMIN . '/tgm/tgm-init.php'; 
require_once NETUBE_ADMIN . '/welcome-page/welcome.php';
//Custom Menu
require_once NETUBE_ADMIN . '/mega-menu/custom_menu.php';
//Zozo Importer
if( class_exists( 'netube_Zozo_Admin_Page' ) ){
	require_once NETUBE_ADMIN . '/welcome-page/importer/zozo-importer.php'; 	
}
//Meta Box
if( class_exists( 'netubeRedux' ) ) {
	require_once NETUBE_ADMIN . '/metabox/inc/netube-metabox.php';
}

//Botstrap Nav Walker
require_once NETUBE_INC . '/walker/wp_bootstrap_navwalker.php';

//News Menu Block
require_once NETUBE_ADMIN . "/mega-menu/menu_news_block.php";

//News Functions
require_once NETUBE_INC . '/news-functions.php';

// Netube AQ Resizer
require_once NETUBE_ADMIN . '/resizer/aq_resizer.php';

//VC Shortcodes
if ( class_exists( 'Vc_Manager' ) ) {
	require_once NETUBE_INC . '/visual-composer/visual-composer.php'; 
}

//Woo
if ( class_exists( 'WooCommerce' ) ) {
	require_once NETUBE_INC . "/woo-functions.php";
}
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function netube_setup() {

	/* netube Text Domain */
	load_theme_textdomain( 'netube', get_template_directory() . '/languages' );
	
	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'post-thumbnails' );
	
	/* Custom background */
	$defaults = array(
		'default-color'          => '',
		'default-image'          => '',
		'wp-head-callback'       => '_custom_background_cb',
		'admin-head-callback'    => '',
		'admin-preview-callback' => ''
	);
	add_theme_support( 'custom-background', $defaults );
	
	/* Custom header */
	$defaults = array(
		'default-image'          => '',
		'random-default'         => false,
		'width'                  => 0,
		'height'                 => 0,
		'flex-height'            => false,
		'flex-width'             => false,
		'default-text-color'     => '',
		'header-text'            => true,
		'uploads'                => true,
		'wp-head-callback'       => '',
		'admin-head-callback'    => '',
		'admin-preview-callback' => '',
	);
	add_theme_support( 'custom-header', $defaults );
	
	/* Content width */
	if ( ! isset( $content_width ) ) $content_width = 640;
	
	$ao = new netubeThemeOpt;
	$grid_large = $ao->netubeThemeOpt('netube_grid_large');
	$grid_medium = $ao->netubeThemeOpt('netube_grid_medium');
	$grid_small = $ao->netubeThemeOpt('netube_grid_small');
	$port_masonry = $ao->netubeThemeOpt('netube_portfolio_masonry');
	
	if( !empty( $grid_large ) && is_array( $grid_large ) ) add_image_size( 'netube-grid-large', $grid_large['width'], $grid_large['height'], true );
	if( !empty( $grid_medium ) && is_array( $grid_medium ) ) add_image_size( 'netube-grid-medium', $grid_medium['width'], $grid_medium['height'], true );
	if( !empty( $grid_small ) && is_array( $grid_small ) ) add_image_size( 'netube-grid-small', $grid_small['width'], $grid_small['height'], true );
	
	//Team
	$team_medium = $ao->netubeThemeOpt('netube_team_medium');
	if( !empty( $team_medium ) && is_array( $team_medium ) ) add_image_size( 'netube-team-medium', $team_medium['width'], $team_medium['height'], true );
	update_option( 'large_size_w', 1170 );
	update_option( 'large_size_h', 694 );
	update_option( 'large_crop', 1 );
	update_option( 'medium_size_w', 768 );
	update_option( 'medium_size_h', 456 );
	update_option( 'medium_crop', 1 );
	update_option( 'thumbnail_size_w', 90 );
	update_option( 'thumbnail_size_h', 90 );
	update_option( 'thumbnail_crop', 1 );
	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'top-menu'		=> esc_html__( 'Top Menu', 'netube' ),
		'primary-menu'	=> esc_html__( 'Primary Menu', 'netube' ),
		'footer-menu'	=> esc_html__( 'Footer Menu', 'netube' ),
	) );
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );
	/*
	 * Enable support for Post Formats.
	 *
	 */
	add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
		'gallery',
		'audio',
	) );
	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo' );
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );

	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );

	// Add support for editor styles.
	add_theme_support( 'editor-styles' );

	// Enqueue editor styles.
	add_editor_style( 'style-editor.css' );

	// Editor color palette.
	add_theme_support(
		'editor-color-palette',
		array(
			array(
				'name'  => __( 'Dark Gray', 'netube' ),
				'slug'  => 'dark-gray',
				'color' => '#111',
			),
			array(
				'name'  => __( 'Light Gray', 'netube' ),
				'slug'  => 'light-gray',
				'color' => '#767676',
			),
			array(
				'name'  => __( 'White', 'netube' ),
				'slug'  => 'white',
				'color' => '#FFF',
			),
		)
	);

	// Add support for responsive embedded content.
	add_theme_support( 'responsive-embeds' );
}
add_action( 'after_setup_theme', 'netube_setup' );
/**
 * Register widget area.
 *
 */
function netube_widgets_init() {
	$netube_option = get_option( 'netube_options' );
	$title_class = '';
	//Widget Title Style
	if( isset( $netube_option['widget-title-style'] ) && $netube_option['widget-title-style'] != '' ){
		$title_class = ' title-style-' . $netube_option['widget-title-style'];
	}
	
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'netube' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here to appear in your sidebar.', 'netube' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title'. esc_attr( $title_class ) .'">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Secondary Menu Sidebar', 'netube' ),
		'id'            => 'secondary-menu-sidebar',
		'description'   => esc_html__( 'Add widgets here to appear in your secondary menu area.', 'netube' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title'. esc_attr( $title_class ) .'">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 1', 'netube' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here to appear in your footer.', 'netube' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title'. esc_attr( $title_class ) .'">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 2', 'netube' ),
		'id'            => 'sidebar-3',
		'description'   => esc_html__( 'Add widgets here to appear in your footer.', 'netube' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title'. esc_attr( $title_class ) .'">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => esc_html__( 'Footer 3', 'netube' ),
		'id'            => 'sidebar-4',
		'description'   => esc_html__( 'Add widgets here to appear in your footer.', 'netube' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title'. esc_attr( $title_class ) .'">',
		'after_title'   => '</h3>',
	) );
	
}
add_action( 'widgets_init', 'netube_widgets_init' );
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with ... and
 * a 'Continue reading' link.
 *
 * @since netube 1.0
 *
 * @return string 'Continue reading' link prepended with an ellipsis.
 */
function netube_excerpt_more( $link ) {
	return '...';
}
add_filter( 'excerpt_more', 'netube_excerpt_more', 99 );
/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function netube_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'netube_pingback_header' );
/**
 * Admin Enqueue scripts and styles.
 */
function netube_enqueue_admin_script() { 
	wp_enqueue_style( 'netube-admin-style', get_theme_file_uri( '/admin/assets/css/admin-style.css' ), array(), '1.0' );
	wp_enqueue_style( 'themify-icons', get_theme_file_uri( '/assets/css/themify-icons.css' ), array(), '1.0' );
	
	// Meta Drag and Drop Script
	wp_enqueue_script( 'netube-admin-scripts', get_theme_file_uri( '/admin/assets/js/admin-scripts.js' ), array( 'jquery' ), '1.0', true ); 
	
	//Admin Localize Script
	wp_localize_script('netube-admin-scripts', 'netube_admin_ajax_var', array(
		'admin_ajax_url' => esc_url( admin_url('admin-ajax.php') ),
		'featured_nonce' => wp_create_nonce('netube-post-featured'), 
		'sidebar_nounce' => wp_create_nonce('netube-sidebar-featured'), 
		'redux_themeopt_import' => wp_create_nonce('netube-redux-import'),
		'unins_confirm' => esc_html__('Please backup your files and database before uninstall. Are you sure want to uninstall current demo?.', 'netube'),
		'yes' => esc_html__('Yes', 'netube'),
		'no' => esc_html__('No', 'netube'),
		'proceed' => esc_html__('Proceed', 'netube'),
		'cancel' => esc_html__('Cancel', 'netube'),
		'block' => esc_html__('Block', 'netube'),
		'edit' => esc_html__('Edit', 'netube'),
		'update' => esc_html__('Update', 'netube'),
		'settings' => esc_html__('Settings', 'netube'),
		'process' => esc_html__( 'Processing', 'netube' ),
		'uninstalling' => esc_html__('Uninstalling...', 'netube'),
		'uninstalled' => esc_html__('Uninstalled.', 'netube'),
		'unins_pbm' => esc_html__('Uninstall Problem!.', 'netube'),
		'downloading' => esc_html__('Downloading Demo Files...', 'netube'), 
		'import_xml' => esc_html__('Importing Xml...', 'netube'),
		'import_theme_opt' => esc_html__('Importing Theme Option...', 'netube'),
		'import_widg' => esc_html__('Importing Widgets...', 'netube'),
		'import_sidebars' => esc_html__('Importing Sidebars...', 'netube'),
		'import_revslider' => esc_html__('Importing Revolution Sliders...', 'netube'),
		'imported' => esc_html__('Successfully Imported, Check Above Message.', 'netube'),
		'import_pbm' => esc_html__('Import Problem.', 'netube'),
		'access_pbm' => esc_html__('File access permission problem.', 'netube'),
		'redux_block_nonce' => wp_create_nonce('netube-redux-news-block'),
		'assets_path' => NETUBE_ASSETS
	));
	
}
add_action( 'admin_enqueue_scripts', 'netube_enqueue_admin_script' );
/**
 * Enqueue scripts and styles.
 */
function netube_scripts() { 

	$minify_js = netubeThemeOpt::netubeStaticThemeOpt('js-minify');
	$minify_css = netubeThemeOpt::netubeStaticThemeOpt('css-minify');
	
	wp_register_style( 'ytplayer', get_theme_file_uri( '/assets/css/ytplayer.min.css' ), array(), '1.0' );
	wp_register_style( 'owl-carousel', get_theme_file_uri( '/assets/css/owl-carousel.min.css' ), array(), '2.2.1' );
	wp_register_style( 'magnific-popup', get_theme_file_uri( '/assets/css/magnific-popup.min.css' ), array(), '1.0' );
	
	if( $minify_css ){
		wp_enqueue_style( 'netube-min', get_theme_file_uri( '/assets/css/theme.min.css' ), array(), '1.0' );
	}else{
		wp_enqueue_style( 'bootstrap', get_theme_file_uri( '/assets/css/bootstrap.min.css' ), array(), '4.1.1' );
		wp_enqueue_style( 'themify-icons', get_theme_file_uri( '/assets/css/themify-icons.css' ), array(), '1.0' );
		wp_enqueue_style( 'animate', get_theme_file_uri( '/assets/css/animate.min.css' ), array(), '3.5.1' );
	}
	
	// Theme stylesheet.
	wp_enqueue_style( 'netube-style', get_template_directory_uri() . '/style.css', array(), '1.0' );
	
	//Demo Style
	$custom_demo_type = netubeThemeOpt::netubeStaticThemeOpt('demo-id-style');
	if( $custom_demo_type != 'none' ){
		if( $custom_demo_type != 'demo-main' ){
			wp_enqueue_style( 'netube-demo-'.$custom_demo_type, get_theme_file_uri( '/assets/css/'. $custom_demo_type .'.css' ), array(), '1.0' );
		}
	}else{
		$demo_type = get_theme_mod('netube_installed_demo_id');
		if( !empty( $demo_type ) && $demo_type != 'demo-main' ){
			wp_enqueue_style( 'netube-demo-'.$demo_type, get_theme_file_uri( '/assets/css/'. $demo_type .'.css' ), array(), '1.0' );
		}
	}
	
	// Load the html5 shiv.
	wp_enqueue_script( 'html5', get_theme_file_uri( '/assets/js/html5.js' ), array(), '3.7.3' );
	wp_script_add_data( 'html5', 'conditional', 'lt IE 9' );
	
	// netube JS Libraries	
	wp_register_script( 'sticky-kit', get_theme_file_uri( '/assets/js/sticky-kit.min.js' ), array( 'jquery' ), '1.1.3', true );
	wp_register_script( 'jquery-easy-ticker', get_theme_file_uri( '/assets/js/jquery.easy.ticker.min.js' ), array( 'jquery' ), '2.0', true );
	wp_register_script( 'jquery-mb-YTPlayer', get_theme_file_uri( '/assets/js/jquery.mb.YTPlayer.min.js' ), array( 'jquery' ), '1.0', true );
	wp_register_script( 'owl-carousel', get_theme_file_uri( '/assets/js/owl.carousel.min.js' ), array( 'jquery' ), '2.2.1', true );
	wp_register_script( 'magnific-popup', get_theme_file_uri( '/assets/js/jquery.magnific.popup.min.js' ), array( 'jquery' ), '1.1.0', true );
	
	$lazy_opt = netubeThemeOpt::netubeStaticThemeOpt('news-lazy-load');
	if( $lazy_opt ){
		wp_enqueue_script( 'imagesloaded' );
	}
	
	$localize_variable = '';
	wp_enqueue_script( 'jquery-easing', get_theme_file_uri( '/assets/js/jquery.easing.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-appear', get_theme_file_uri( '/assets/js/jquery.appear.min.js' ), array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'smartresize', get_theme_file_uri( '/assets/js/smartresize.min.js' ), array( 'jquery' ), '1.0', true );
	// Theme Js
	wp_enqueue_script( 'netube-theme', get_theme_file_uri( '/assets/js/theme-function.js' ), array( 'jquery' ), '1.0', true );
	$localize_variable = 'netube-theme';
	// News Block Js
	wp_enqueue_script( 'netube-block', get_theme_file_uri( '/assets/js/news-block.js' ), array( 'jquery' ), '1.0', true );
	
	$smooth_scroll_opt = netubeThemeOpt::netubeStaticThemeOpt('smooth-opt');
	if( $smooth_scroll_opt  ){
		wp_enqueue_script( 'smoothscroll', get_theme_file_uri( '/assets/js/smoothscroll.min.js' ), array( 'jquery' ), '1.20.2', true );
	}
		
	//Comment Js
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	
	// Theme option stylesheet.
	$upload_dir = wp_upload_dir();
	$netube = wp_get_theme();
	$theme_style = $upload_dir['baseurl'] . '/netube/theme_'.get_current_blog_id().'.css';
	wp_enqueue_style( 'netube-theme-style', esc_url( $theme_style ), array(), $netube->get( 'Version' ) );
		
	$infinite_img = netubeThemeOpt::netubeStaticThemeOpt('infinite-loader-img');
	$infinite_img_url = isset( $infinite_img['url'] ) && $infinite_img['url'] != '' ? $infinite_img['url'] : get_theme_file_uri( '/assets/images/infinite-loder.gif' );
	
	//Youtube api
	$yt_api = netubeThemeOpt::netubeStaticThemeOpt('youtube-api');
	
	//Localize Script
	wp_localize_script( $localize_variable, 'netube_ajax_var', array(
		'admin_ajax_url' => esc_url( admin_url('admin-ajax.php') ),
		'like_nonce' => wp_create_nonce('netube-post-like'), 
		'fav_nonce' => wp_create_nonce('netube-post-fav'),
		'infinite_loader' => esc_url( $infinite_img_url ),
		'load_posts' => apply_filters( 'infinite_load_msg', esc_html__( 'Loading next set of posts.', 'netube' ) ),
		'no_posts' => apply_filters( 'infinite_finished_msg', esc_html__( 'No more posts to load.', 'netube' ) ),
		'cmt_nonce' => wp_create_nonce('netube-comment-like'),
		'mc_nounce' => wp_create_nonce('netube-mailchimp'), 
		'wait' => esc_html__('Wait..', 'netube'),
		'must_fill' => esc_html__('Must Fill Required Details.', 'netube'),
		'valid_email' => esc_html__('Enter Valid Email ID.', 'netube'),
		'cart_update_pbm' => esc_html__('Cart Update Problem.', 'netube'),
		'news_problem' => esc_html__('News Retrieve Problem.', 'netube'),
		'redirecturl' => home_url( '/' ),
        'loadingmessage' => esc_html__( 'Sending user info, please wait...', 'netube' ),
		'valid_email' => esc_html__( 'Please enter valid email!', 'netube' ),
		'valid_login' => esc_html__( 'Please enter valid username/password!', 'netube' ),
		'req_reg' => esc_html__( 'Please enter required fields values for registration!', 'netube' ),
		'lazy_opt' => esc_attr( $lazy_opt ),
		'yt_api'	=> esc_attr( $yt_api ),
		'netube_filter_nce' => wp_create_nonce( 'netube-filter-search-nonce' )
	));
	
}
add_action( 'wp_enqueue_scripts', 'netube_scripts' );

/**
 * Enqueue supplemental block editor styles.
 */
function netube_editor_customizer_styles() {
	wp_enqueue_style( 'google-fonts', netube_redux_fonts_url(), array(), null, 'all' );
	wp_enqueue_style( 'netube-editor-customizer-styles', get_theme_file_uri( '/style-editor-customizer.css' ), false, '1.0', 'all' );

	if( function_exists('netube_get_custom_styles') ) {
		wp_add_inline_style( 'netube-editor-customizer-styles', netube_get_custom_styles() );
	}
}
add_action( 'enqueue_block_editor_assets', 'netube_editor_customizer_styles' );

/**
 * Additional features to allow styling of the templates.
 */
require get_parent_theme_file_path( '/inc/template-functions.php' );
/*Theme Code*/
/*Search Form Filter*/
if( ! function_exists('netube_zozo_search_form') ) {
	function netube_zozo_search_form( $form ) {
		
		$search_out = '
		<form method="get" class="search-form" action="'. esc_url( home_url( '/' ) ) .'">
			<div class="input-group">
				<input type="text" class="form-control" name="s" value="'. esc_attr( get_search_query() ) .'" placeholder="'. esc_attr__('Search for...', 'netube') .'">
				<span class="input-group-btn">
					<button class="btn btn-secondary" type="submit"><i class="ti-search"></i></button>
				</span>
			</div>
		</form>';
		return $search_out;
	}
	add_filter( 'get_search_form', 'netube_zozo_search_form' );
}
$aps = new netubePostSettings;
add_action( 'wp_ajax_post_like_act', array( &$aps, 'netubeMetaLikeCheck' ) );
add_action( 'wp_ajax_nopriv_post_like_act', array( &$aps, 'netubeMetaLikeCheck' ) ); 
add_action( 'wp_ajax_post_fav_act', array( &$aps, 'netubeMetaFavouriteCheck' ) );
add_action( 'wp_ajax_nopriv_post_fav_act', array( &$aps, 'netubeMetaFavouriteCheck' ) );
if( $aps->netubeGetThemeOpt( 'comments-like' ) ){
	add_action('wp_ajax_nopriv_comment_like', array( &$aps, 'netubeCommentsLike' ) );
	add_action('wp_ajax_comment_like', array( &$aps, 'netubeCommentsLike' ) );
}
if( ! function_exists('netubePostComments') ) {
	function netubePostComments( $comment, $args, $depth ) {
	
		$GLOBALS['comment'] = $comment;
		
		$aps = new netubePostSettings;		
		
		$allowed_html = array(
			'a' => array(
				'href' => array(),
				'title' => array()
			)
		);
		
		?>
		<li <?php comment_class('clearfix'); ?> id="comment-<?php comment_ID() ?>">
			
			<div class="media thecomment">
						
				<div class="media-left author-img">
					<?php echo get_avatar($comment,$args['avatar_size']); ?>
				</div>
				
				<div class="media-body comment-text">
					<div class="comment-meta">
					<?php if( $depth < $args['max_depth'] ) : ?>
					
					<?php endif; ?>
					<h6 class="author"><?php echo get_comment_author_link(); ?></h6>
					<span class="date"><?php printf( wp_kses( __( '%1$s at %2$s', 'netube' ), $allowed_html ), get_comment_date(),  get_comment_time()) ?></span>
					<?php if ( $comment->comment_approved == '0' ) : ?>
						<em><i class="icon-info-sign"></i> <?php esc_html_e( 'Comment awaiting approval', 'netube' ); ?></em>
						<br />
					<?php endif; ?>
					<?php comment_text(); ?>
					<span class="reply">
						<?php comment_reply_link( array_merge( $args, array('reply_text' => 'Reply ', 'depth' => $depth, 'max_depth' => $args['max_depth'])), $comment->comment_ID ); ?>
					</span>
					<!-- Custom Comments Meta -->
					<?php if( $aps->netubeGetThemeOpt( 'comments-like' ) || $aps->netubeGetThemeOpt( 'comments-share' ) ) : ?>
						<div class="comment-meta-wrapper clearfix">
							<ul class="list-inline">
								<?php if( $aps->netubeGetThemeOpt( 'comments-like' ) ) : ?>
								<li class="comment-like-wrapper"><?php echo do_shortcode( $aps->netubeCommentLikeOut( $comment->comment_ID ) ); ?></li>
								<?php endif; ?>
								<?php if( $aps->netubeGetThemeOpt( 'comments-social-shares' )) : ?>
								<li class="comment-share-wrapper pull-right"><?php echo do_shortcode( $aps->netubeCommentShare( $comment->comment_ID ) ); ?></li>
								<?php endif; ?>
							</ul>
						</div>
					</div>
					<?php endif; // if comment meta need ?>
				</div>
						
			</div>
			
			
		</li>
		<?php
		
	} 
}