<?php
/**
 * Additional features to allow styling of the templates
 */
function netube_custom_scripts() {
	
	global $netube_custom_styles;
	
	if( netube_po_exists() ):
		
		// Page Styles
		require_once NETUBE_THEME_ELEMENTS . '/page-styles.php';
		ob_start();
		netube_page_custom_styles();
		$netube_custom_styles = ob_get_clean();
		wp_add_inline_style( 'netube-theme-style', $netube_custom_styles );
		
	elseif( is_single() && has_post_format( 'quote' ) ):
		$meta_opt = get_post_meta( get_the_ID(), 'netube_post_quote_modal', true );
		if( $meta_opt != '' && $meta_opt != 'theme-default' ) :
			$aps = new netubePostSettings;
			$theme_color = $aps->netubeThemeColor();
			$rgba_08 = $aps->netubeHex2Rgba( $theme_color, '0.8' ); 
			$blockquote_bg_opt = $aps->netubeCheckMetaValue( 'netube_post_quote_modal', 'single-post-quote-format' );
			ob_start();
			$aps->netubeQuoteDynamicStyle( 'single-post', $blockquote_bg_opt, $theme_color, $rgba_08 );
			$netube_custom_styles .= ob_get_clean();
		endif;
	elseif( is_single() && has_post_format( 'link' ) ):
		$meta_opt = get_post_meta( get_the_ID(), 'netube_post_link_modal', true );
		if( $meta_opt != '' && $meta_opt != 'theme-default' ) :
			$aps = new netubePostSettings;
			$theme_color = $aps->netubeThemeColor();
			$rgba_08 = $aps->netubeHex2Rgba( $theme_color, '0.8' ); 
			$blockquote_bg_opt = $aps->netubeCheckMetaValue( 'netube_post_link_modal', 'single-post-link-format' );
			ob_start();
			$aps->netubeLinkDynamicStyle( 'single-post', $blockquote_bg_opt, $theme_color, $rgba_08 );
			$netube_custom_styles .= ob_get_clean();
		endif;
	endif;
	
	if( is_single() ){
		// Page Styles
		require_once NETUBE_THEME_ELEMENTS . '/page-styles.php';
		ob_start();
		netube_post_custom_styles();
		$netube_custom_styles .= ob_get_clean();
	}
	
	if( is_single() && !empty( $netube_custom_styles ) ):
		wp_add_inline_style( 'netube-theme-style', $netube_custom_styles );
	endif;
	
}
add_action( 'wp_enqueue_scripts', 'netube_custom_scripts' );

function netube_rtl_body_classes( $classes ) {
    $classes[] = 'rtl';
    return $classes;     
}

function netube_lazy_body_classes( $classes ) {
    $classes[] = 'netube-lazy-active';
    return $classes;     
}

add_action('wp_ajax_netube-post-featured-active', 'netube_post_featured_active');
function netube_post_featured_active(){
	$nonce = sanitize_text_field($_POST['nonce']);
  
    if ( ! wp_verify_nonce( $nonce, 'netube-post-featured' ) )
        die ( esc_html__( 'Busted!', 'netube' ) );
	
	update_post_meta( esc_attr( $_POST['postid'] ), 'netube_post_featured_stat', esc_attr($_POST['featured-stat']) );
	exit;
}
add_action('wp_ajax_netube-custom-sidebar-export', 'netube_custom_sidebar_export');
function netube_custom_sidebar_export(){
	$nonce = sanitize_text_field($_POST['nonce']);
  
    if ( ! wp_verify_nonce( $nonce, 'netube-sidebar-featured' ) )
        die ( esc_html__( 'Busted!', 'netube' ) );
	
	$sidebar = get_option('netube_custom_sidebars');
	echo ( ''. $sidebar );
	
	exit;
}
function netube_ads_out( $field ){
	$ato = new netubeThemeOpt;
	$output = '';
	if( $ato->netubeThemeOpt( $field.'-ads-text' ) ){
		$ads_hide = '';
		if( $ato->netubeThemeOpt( $field.'-ads-md' ) == 'no' ){
			$ads_hide .= 'hidden-xs-up ';
		}
		if( $ato->netubeThemeOpt( $field.'-ads-sm' ) == 'no' ){
			$ads_hide .= 'hidden-md-down ';
		}
		if( $ato->netubeThemeOpt( $field.'-ads-xs' ) == 'no' ){
			$ads_hide .= 'hidden-sm-down ';
		}
		$ads_code = $ato->netubeThemeOpt( $field.'-ads-text' );
		$output = '<div class="adv-wrapper '. esc_attr( $ads_hide ) .'">'. apply_filters( 'netube_ads_output_form', $ads_code ) .'</div>';
	}
	return $output;
}
function netube_po_exists( $post_id = '' ){
	$post_id = $post_id ? $post_id : get_the_ID();
	$stat = get_post_meta( $post_id, 'netube_page_layout', true );
	
	if( $stat )
		return true;
	else
		return false;
}
if( ! function_exists('netube_mailchimp') ) {
	function netube_mailchimp(){
		$nonce = sanitize_text_field($_POST['nonce']);
	  
		if ( ! wp_verify_nonce( $nonce, 'netube-mailchimp' ) )
			die ( esc_html__( 'Busted', 'netube' ) );
		if( isset( $_POST['netube_mc_number'] ) ) {
			
			$first_name = 'zozo-mc-first_name' . esc_attr( $_POST['netube_mc_number'] );
			$last_name = 'zozo-mc-last_name' . esc_attr( $_POST['netube_mc_number'] );
			$email = 'zozo-mc-email' . esc_attr( $_POST['netube_mc_number'] );
			$success = 'netube_mc_success' . esc_attr( $_POST['netube_mc_number'] );
			$failure = 'netube_mc_failure' . esc_attr( $_POST['netube_mc_number'] );
			$listid = 'netube_mc_listid' . esc_attr( $_POST['netube_mc_number'] );
				
			$ato = new netubeThemeOpt;
			$mc_key = $ato->netubeThemeOpt( 'mailchimp-api' );
			$mcapi = new MCAPI( $mc_key );
			
			$merge_vars = array();
			$merge_vars['FNAME'] = isset($_POST[$first_name]) ? strip_tags($_POST[$first_name]) : '';
			$merge_vars['LNAME'] = isset($_POST[$last_name]) ? strip_tags($_POST[$last_name]) : '';
			$subscribed = $mcapi->listSubscribe(strip_tags($_POST[$listid]), strip_tags($_POST[$email]), $merge_vars);
			
			if ($subscribed != false) {
				echo stripslashes($_POST[$success]);
			}else{
				echo stripslashes($_POST[$failure]);
			}
		}
		wp_die();
	}
	add_action('wp_ajax_nopriv_zozo-mc', 'netube_mailchimp');
	add_action('wp_ajax_zozo-mc', 'netube_mailchimp');
}
if( ! function_exists('netube_star_rating') ) {
	function netube_star_rating( $rate ){
		$out = '';
		for( $i=1; $i<=5; $i++ ){
			
			if( $i == round($rate) ){
				if ( $i-0.5 == $rate ) {
					$out .= '<i class="ti-star ti-star-half"></i>';
				}else{
					$out .= '<i class="ti-star"></i>';
				}
			}else{
				if( $i < $rate ){
					$out .= '<i class="ti-star ti-star-filled"></i>';
				}else{
					$out .= '<i class="ti-star"></i>';
				}
			}
		}// for end
		
		return $out;
	}
}
/*Search Options*/
if( ! function_exists('netube_search_post') ) {
	function netube_search_post($query) {
		if ($query->is_search) {
			$query->set('post_type',array('post'));
		}
	return $query;
	}
}
if( ! function_exists('netube_search_page') ) {
	function netube_search_page($query) {
		if ($query->is_search) {
			$query->set('post_type',array('page'));
		}
	return $query;
	}
}
if( ! function_exists('netube_search_setup') ) {
	function netube_search_setup(){
		$ato = new netubeThemeOpt;
		$search_cont = $ato->netubeThemeOpt( 'search-content' );
		if( $search_cont == "post" ){
			add_filter('pre_get_posts','netube_search_post');
		}elseif( $search_cont == "page" ){
			add_filter('pre_get_posts','netube_search_page');
		}
	}
	add_action( 'after_setup_theme', 'netube_search_setup' );
}
//Return same value for filter
if( ! function_exists('__return_value') ) {
	function __return_value( $value ) {
		return function () use ( $value ) {
			return $value; 
		};
	}
}
if( !function_exists( 'netubeGetCSSAnimation' ) && class_exists( 'Vc_Manager' ) ) {
	function netubeGetCSSAnimation( $css_animation ) {
		$output = '';
		if ( '' !== $css_animation && 'none' !== $css_animation ) {
			wp_enqueue_script( 'vc_waypoints' );
			wp_enqueue_style( 'vc_animate-css' );
			$output = ' wpb_animate_when_almost_visible wpb_' . $css_animation . ' ' . $css_animation;
		}
	
		return $output;
	}
}
/*Facebook Comments Code*/
if( ! function_exists('netube_fb_comments_code') ) {
	function netube_fb_comments_code(){
		$ato = new netubeThemeOpt;
		$fb_width = $ato->netubeThemeOpt( 'fb-comments-width' );
		$fb_width = isset( $fb_width['width'] ) && $fb_width['width'] != '' ? esc_attr( $fb_width['width'] ) : '300px';
		$comment_num = $ato->netubeThemeOpt( 'fb-comments-number' );
		$fb_number = $comment_num != '' ? absint( $comment_num ) : '5';
?>
		<div class="fb-comments" data-href="<?php esc_url( the_permalink() ); ?>" data-width="<?php echo esc_attr( $fb_width ); ?>" data-numposts="<?php echo esc_attr( $fb_number ); ?>"></div>
	<?php
	}
}
if( !function_exists( 'netube_shortcode_rand_id' ) ) {
	function netube_shortcode_rand_id() {
		static $shortcode_rand = 1;
		return $shortcode_rand++;
	}
}
function netube_get_categories_now( $string, $arg1, $arg2 ) {
    $cats = get_categories( array(
		'orderby' => 'name',
		'order'   => 'ASC'
	) );
    return $cats;
}
add_filter( 'netube_get_categories', 'netube_get_categories_now', 10 );

//Check title with tagline
function netube_display_header_text() {
	if ( ! current_theme_supports( 'custom-header', 'header-text' ) )
	return false;
	
	$text_color = get_theme_mod( 'header_textcolor', get_theme_support( 'custom-header', 'default-text-color' ) );
	return 'blank' !== $text_color;
}

// Wp List Categories Count Span
add_filter( 'wp_list_categories', 'netube_cat_count_span' );
function netube_cat_count_span($links) {
	$links = str_replace('</a> (', ' <span class="cat-count">(', $links);
	$links = str_replace(')', ')</span></a>', $links);
	return $links;
}

function getTemplatePageURL( $template_name ){
    $url = null;
    $pages = get_pages(array(
        'meta_key' => '_wp_page_template',
        'meta_value' => $template_name
    ));
    if(isset($pages[0])) {
        $url = get_page_link($pages[0]->ID);
    }
    return $url;
}

if( ! function_exists('netube_filter_search_function') ) {
	
	function netube_filter_search_function() {
	
		$nonce = sanitize_text_field($_POST['nonce']);
	  	if ( ! wp_verify_nonce( $nonce, 'netube-filter-search-nonce' ) ) die ( esc_html__( 'Busted', 'netube' ) );
		
		$cat_id = isset( $_POST['cat_id'] ) ? $_POST['cat_id'] : '';
		$srch_key = isset( $_POST['key_val'] ) ? $_POST['key_val'] : '';
		
		$args = array( 
			'cat'	=> esc_attr( $cat_id ),
			's'		=> esc_attr( $srch_key ),
			'ignore_sticky_posts' => 1
		);
		
		$result = '';
		
		// The Query
		$the_query = new WP_Query( $args );
		
		// The Loop
		if ( $the_query->have_posts() ) {
			$result .= '<ul class="nav flex-column">';
			while ( $the_query->have_posts() ) {
				$the_query->the_post();
				$result .= '<li><a href="'. esc_url( get_the_permalink() ) .'">' . esc_html( get_the_title() ) . '</a></li>';
			}
			$result .= '</ul>';
			/* Restore original Post Data */
			wp_reset_postdata();
		} else {
			$result .= esc_html__( 'No posts found', 'netube' );
		}
		
		echo json_encode( array( 'msg' => $result ) );
		
		wp_die();		
	}
	
	add_action('wp_ajax_nopriv_netube_filter_search', 'netube_filter_search_function');
	add_action('wp_ajax_netube_filter_search', 'netube_filter_search_function');
}